@@ -138,7 +138,8 @@ public:
 
   void SetValue()
   {
-    if (seconds->IsNull()) {
+    if (!seconds.Valid() ||
+        seconds->IsNull()) {
       value->SetText(L"-:--");
     }
     else {
