@@ -58,6 +58,8 @@ Selector::Selector(Lum::Model::SizeT *seconds)
   Observe(GetClosedAction());
   Observe(okAction);
 
+  okAction->Disable();
+
   list->SetEmptyText(_(L"TBL_TEA_EMPTY",L"(No teas defined)"));
 }
 
@@ -157,7 +159,8 @@ void Selector::Resync(Lum::Base::Model *model, const Lum::Base::ResyncMsg& msg)
 
     delete teeEdit;
   }
-  else if (model==editAction && editAction->IsFinished()) {
+  else if (model==editAction &&
+           editAction->IsFinished()) {
     assert(selection->HasSelection());
 
     Lum::Model::StringRef name=new Lum::Model::String(teas[selection->GetLine()-1].name);
