@@ -153,6 +153,8 @@ private:
   Lum::Model::ActionRef              removeAction;
   Lum::Model::ActionRef              okAction;
 
+  bool                               success;
+
 public:
   Selector(Lum::Model::SizeT *seconds);
   ~Selector();
@@ -161,6 +163,8 @@ public:
   void GetActions(std::vector<Lum::Dlg::ActionInfo>& actions);
 
   void Resync(Lum::Base::Model *model, const Lum::Base::ResyncMsg& msg);
+
+  bool Success() const;
 };
 
 #endif
