@@ -112,7 +112,8 @@ Lum::OS::Font* StopWatch::FindFont(size_t& digitWidth, size_t& divWidth)
       digitWidth=w;
       divWidth=tmpFont->StringWidth(L":",fontStyle);
 
-      if (3*digitWidth+divWidth+2*digitWidth<=width && tmpFont->pixelHeight<=height) {
+      if (3*digitWidth+divWidth+2*digitWidth<=width &&
+          tmpFont->pixelHeight<=height) {
         return tmpFont;
       }
     }
